@@ -1,9 +1,8 @@
-#encoding: utf-8
-
+#!/usr/bin/python
+# -*- coding: utf-8 -*-
 import requests
-import sys
 import re
-from bs4 import BeautifulSoup
+
 
 class SpiderBase(object):
 
@@ -12,12 +11,12 @@ class SpiderBase(object):
 
 class HuangliSpider(SpiderBase):
 
-
     api_url = "https://nongli.911cha.com/"
+
     def get_current_calender(self):
         html = requests.get(self.api_url,headers=self.headers).text
         re_pattern = "今日.*?年柱.*?<br />(.*?)</td>.*?月柱.*?<br />(.*?)</td>.*?日柱.*?<br />(.*?)</td>.*?时柱.*?<br />(.*?)</td>"
-        r = re.search(re_pattern,html)
+        r = re.search(re_pattern,html.encode("utf-8"))
         return r.group(1),r.group(2),r.group(3),r.group(4)
 
 
